dwww Home | Manual pages | Find package

SAMBA-LOG-PARSER(1)              User Commands              SAMBA-LOG-PARSER(1)

NAME
       samba-log-parser - Samba (winbind) trace parser.

       options:
         -h, --help     show this help message and exit
         --traceid ID   specify the traceid of the trace records
         --pid PID      specify the pid of winbind client
         --breakdown    breakdown the traces into per traceid files
         --merge-by-timestamp   merge logs by timestamp
         --flow         show the request/sub-request flow traces
         --flow-compact show the request/sub-request flow traces without dcerpc
       details

SYNOPSIS

       samba-log-parser {path} [--pid=PID] [--traceid=ID] [--breakdown]
        [--merge-by-timestamp] [--flow] [--flow-compact] [-h|--help]

DESCRIPTION
       This tool is part of the samba(7) suite.

       The samba-log-parser program parses samba winbind logs.

OPTIONS
       The following options are available to the samba-log-parser program.

       --pid=PID
           Display traces for winbind client with the matching PID.

       --traceid=ID
           Display traces with matching traceid debug header field.

       --breakdown
           Break down all traces to separate files in the current working
           directory. For each traceid, three files are created: traceid.full
           traceid.flow traceid.flowcompact

       --merge-by-timestamp
           Sort the trace lines according to the timestamp. Works with log
           files without traceid header field as well.

       --flow
           Display the request/sub-request flow.

       --flow-compact
           Display the request/sub-request flow without dcerpc call details.

EXAMPLES
       Show the flow traces for trace id 1234 from log file log.winbind:

                # samba-log-parser --traceid 1234 --flow /var/log/samba/log.winbind

       Show the full traces for winbind client with PID 999999 sorted using the
       timestamp for log files found in the samba log directory:

                # samba-log-parser --pid 999999 --merge-by-timestamp /var/log/samba

       Break down the traces into separate files according to traceid sorted
       using the timestamp for log files found in the samba log directory:

                # samba-log-parser --breakdown --merge-by-timestamp /var/log/samba

       Sort traces using the timestamp for log files found in the samba log
       directory. Traces do not need to contain the traceid header field.

                # samba-log-parser --merge-by-timestamp /var/log/samba

VERSION
       This man page is part of version 4.22.11-Debian-4.22.11+dfsg-0+deb13u1
       of the Samba suite.

AUTHOR
       The original Samba software and related utilities were created by Andrew
       Tridgell. Samba is now developed by the Samba Team as an Open Source
       project similar to the way the Linux kernel is developed.

Samba 4.22.11-Debian-4.22.11+d     07/28/2026               SAMBA-LOG-PARSER(1)

Generated by dwww version 1.16 on Sat Oct 3 08:32:49 CEST 2026.